@@ -4,6 +4,8 @@ import logging
 import ssl
 from os import strerror
 from pathlib import Path
+from sys import version_info
+from typing import Coroutine
 
 from aiosmtpd.controller import Controller
 from aiosmtpd.smtp import SMTP
@@ -11,6 +13,9 @@ from aiosmtpd.smtp import SMTP
 from .configuration import Config
 from .handlers import AuthMessage
 
+# For use as a type alias in AuthController._run
+AsyncServer = asyncio.base_events.Server
+
 log = logging.getLogger(__name__)
 
 
@@ -19,7 +24,7 @@ class AuthController(Controller):
                  loop=None,
                  hostname=None,
                  port=None,
-                 ready_timeout=1.0,
+                 ready_timeout=None,
                  ssl_context=None,
                  config=None,
                  authenticator=None,
@@ -32,6 +37,7 @@ class AuthController(Controller):
         _handler = AuthMessage(messages=self._messages)
         _hostname = hostname or self.config.host
         _port = int(port or self.config.port)
+        _ready_timeout = float(ready_timeout or self.config.ready_timeout)
         _loop = loop or asyncio.new_event_loop()
         _loop.set_exception_handler(self._handle_exception)
 
@@ -47,9 +53,10 @@ class AuthController(Controller):
                          hostname=_hostname,
                          port=_port,
                          loop=_loop,
-                         ready_timeout=ready_timeout,
+                         ready_timeout=_ready_timeout,
                          ssl_context=context_or_none(),
-                         authenticator=self._authenticator)
+                         authenticator=self._authenticator,
+                         **kwargs)
 
         # The event handler for changes to the config goes here to prevent it
         # firing when the obkect is initialized.
@@ -112,6 +119,44 @@ class AuthController(Controller):
         self.smtpd.transport.close()
         self.server.close()
 
+    def _run(self, ready_event):
+        asyncio.set_event_loop(self.loop)
+        try:
+            # Need to do two-step assignments here to ensure IDEs can properly
+            # detect the types of the vars. Cannot use `assert isinstance`,
+            # because Python 3.6 in asyncio debug mode has a bug wherein
+            # CoroWrapper is not an instance of Coroutine
+            coro_kwargs = {}
+            if self.ssl_context and version_info >= (3, 7):
+                coro_kwargs["ssl_handshake_timeout"] = 5.0
+
+            srv_coro: Coroutine = self.loop.create_server(
+                self._factory_invoker,
+                host=self.hostname,
+                port=self.port,
+                ssl=self.ssl_context,
+                **coro_kwargs
+            )
+            self.server_coro = srv_coro
+            srv: AsyncServer = self.loop.run_until_complete(srv_coro)
+            self.server = srv
+        except Exception as error:  # pragma: on-wsl; # pragma: no cover
+            # Usually will enter this part only if create_server() cannot bind
+            # to the specified host:port.
+            #
+            # Somehow WSL 1.0 (Windows Subsystem for Linux) allows multiple
+            # listeners on one port?!
+            # That is why we add "pragma: on-wsl" there, so this block will not
+            # affect coverage on WSL 1.0.
+            self._thread_exception = error
+            return
+        self.loop.call_soon(ready_event.set)
+        self.loop.run_forever()
+        self.server.close()
+        self.loop.run_until_complete(self.server.wait_closed())
+        self.loop.close()
+        self.server = None
+
     def reset(self, persist_messages=True):
         _running = False
         try:
